@@ -176,8 +176,10 @@ static void updatePorts(DeviceWidget *w, std::map<QByteArray, PortInfo> &ports)
     }
 }
 
-static void setIconByName(QLabel* label, const char* name) {
-    QIcon icon = QIcon::fromTheme(QString::fromUtf8(name));
+static void setIconByName(QLabel* label, const char* name, const char* fallback_name = nullptr) {
+    QIcon icon = QIcon::fromTheme(QString::fromLatin1(name));
+    if (icon.isNull() || icon.availableSizes().isEmpty())
+        icon = QIcon::fromTheme(QString::fromLatin1(fallback_name));
     int size = label->style()->pixelMetric(QStyle::PM_ToolBarIconSize);
     QPixmap pix = icon.pixmap(size, size);
     label->setPixmap(pix);
@@ -205,11 +207,11 @@ void MainWindow::updateCard(const pa_card_info &info) {
     w->nameLabel->setText(QString::fromUtf8(w->name));
 
     icon = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_ICON_NAME);
-    setIconByName(w->iconImage, icon ? icon : "audio-card");
+    setIconByName(w->iconImage, icon, "audio-card");
 
     w->hasSinks = w->hasSources = false;
     profile_priorities.clear();
-    for (pa_card_profile_info2 ** p_profile = info.profiles2; *p_profile != nullptr; ++p_profile) {
+    for (pa_card_profile_info2 ** p_profile = info.profiles2; p_profile && *p_profile != nullptr; ++p_profile) {
         w->hasSinks = w->hasSinks || ((*p_profile)->n_sinks > 0);
         w->hasSources = w->hasSources || ((*p_profile)->n_sources > 0);
         profile_priorities.insert(*p_profile);
@@ -225,7 +227,7 @@ void MainWindow::updateCard(const pa_card_info &info) {
         p.available = info.ports[i]->available;
         p.direction = info.ports[i]->direction;
         p.latency_offset = info.ports[i]->latency_offset;
-        for (pa_card_profile_info2 ** p_profile = info.ports[i]->profiles2; *p_profile != nullptr; ++p_profile)
+        for (pa_card_profile_info2 ** p_profile = info.ports[i]->profiles2; p_profile && *p_profile != nullptr; ++p_profile)
             p.profiles.push_back((*p_profile)->name);
 
         w->ports[p.name] = p;
@@ -336,7 +338,7 @@ bool MainWindow::updateSink(const pa_sink_info &info) {
     g_free(txt);
 
     icon = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_ICON_NAME);
-    setIconByName(w->iconImage, icon ? icon : "audio-card");
+    setIconByName(w->iconImage, icon, "audio-card");
 
     w->setVolume(info.volume);
     w->muteToggleButton->setChecked(info.mute);
@@ -502,7 +504,7 @@ void MainWindow::updateSource(const pa_source_info &info) {
     g_free(txt);
 
     icon = pa_proplist_gets(info.proplist, PA_PROP_DEVICE_ICON_NAME);
-    setIconByName(w->iconImage, icon ? icon : "audio-input-microphone");
+    setIconByName(w->iconImage, icon, "audio-input-microphone");
 
     w->setVolume(info.volume);
     w->muteToggleButton->setChecked(info.mute);
@@ -573,7 +575,7 @@ void MainWindow::setIconFromProplist(QLabel *icon, pa_proplist *l, const char *d
 
 finish:
 
-    setIconByName(icon, t);
+    setIconByName(icon, t, def);
 }
 
 
@@ -1093,7 +1095,7 @@ void MainWindow::setConnectingMessage(const char *string) {
     connectingLabel->setText(QString::fromUtf8(markup));
 }
 
-void MainWindow::onSinkTypeComboBoxChanged(int index) {
+void MainWindow::onSinkTypeComboBoxChanged(int /*index*/) {
     showSinkType = (SinkType) sinkTypeComboBox->currentIndex();
 
     if (showSinkType == (SinkType) -1)
@@ -1102,7 +1104,7 @@ void MainWindow::onSinkTypeComboBoxChanged(int index) {
     updateDeviceVisibility();
 }
 
-void MainWindow::onSourceTypeComboBoxChanged(int index) {
+void MainWindow::onSourceTypeComboBoxChanged(int /*index*/) {
     showSourceType = (SourceType) sourceTypeComboBox->currentIndex();
 
     if (showSourceType == (SourceType) -1)
@@ -1111,7 +1113,7 @@ void MainWindow::onSourceTypeComboBoxChanged(int index) {
     updateDeviceVisibility();
 }
 
-void MainWindow::onSinkInputTypeComboBoxChanged(int index) {
+void MainWindow::onSinkInputTypeComboBoxChanged(int /*index*/) {
     showSinkInputType = (SinkInputType) sinkInputTypeComboBox->currentIndex();
 
     if (showSinkInputType == (SinkInputType) -1)
@@ -1120,7 +1122,7 @@ void MainWindow::onSinkInputTypeComboBoxChanged(int index) {
     updateDeviceVisibility();
 }
 
-void MainWindow::onSourceOutputTypeComboBoxChanged(int index) {
+void MainWindow::onSourceOutputTypeComboBoxChanged(int /*index*/) {
     showSourceOutputType = (SourceOutputType) sourceOutputTypeComboBox->currentIndex();
 
     if (showSourceOutputType == (SourceOutputType) -1)
@@ -1130,7 +1132,7 @@ void MainWindow::onSourceOutputTypeComboBoxChanged(int index) {
 }
 
 
-void MainWindow::onShowVolumeMetersCheckButtonToggled(bool toggled) {
+void MainWindow::onShowVolumeMetersCheckButtonToggled(bool /*toggled*/) {
     bool state = showVolumeMetersCheckButton->isChecked();
     pa_operation *o;
 
