@@ -6,7 +6,7 @@
     <message>
         <location filename="../cardwidget.ui" line="14"/>
         <source>Form</source>
-        <translation></translation>
+        <translation>Formular</translation>
     </message>
     <message>
         <location filename="../cardwidget.ui" line="29"/>
@@ -19,7 +19,7 @@
         <translation>Profil:</translation>
     </message>
     <message>
-        <location filename="../cardwidget.cc" line="68"/>
+        <location filename="../cardwidget.cc" line="67"/>
         <source>pa_context_set_card_profile_by_index() failed</source>
         <translation>pa_context_set_card_profile_by_index() virket ikke</translation>
     </message>
@@ -46,7 +46,7 @@
     <message>
         <location filename="../channel.cc" line="160"/>
         <source>&lt;small&gt;Min&lt;/small&gt;</source>
-        <translation></translation>
+        <translation>&lt;small&gt;Min.&lt;/small&gt;</translation>
     </message>
     <message>
         <location filename="../channel.cc" line="162"/>
@@ -56,7 +56,7 @@
     <message>
         <location filename="../channel.cc" line="165"/>
         <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
-        <translation></translation>
+        <translation>&lt;small&gt;&lt;i&gt;Basis&lt;/i&gt;&lt;/small&gt;</translation>
     </message>
 </context>
 <context>
@@ -64,7 +64,7 @@
     <message>
         <location filename="../channelwidget.ui" line="14"/>
         <source>Form</source>
-        <translation></translation>
+        <translation>Formular</translation>
     </message>
     <message>
         <location filename="../channelwidget.ui" line="20"/>
@@ -82,7 +82,7 @@
     <message>
         <location filename="../devicewidget.ui" line="14"/>
         <source>Form</source>
-        <translation></translation>
+        <translation>Formular</translation>
     </message>
     <message>
         <location filename="../devicewidget.ui" line="36"/>
@@ -102,7 +102,7 @@
     <message>
         <location filename="../devicewidget.ui" line="85"/>
         <source>Set as fallback</source>
-        <translation>Fall tilbake på denne</translation>
+        <translation>Sett som reserve</translation>
     </message>
     <message>
         <location filename="../devicewidget.ui" line="103"/>
@@ -162,7 +162,7 @@
     <message>
         <location filename="../devicewidget.cc" line="155"/>
         <source>pa_context_set_port_latency_offset() failed</source>
-        <translation>pa_context_set_port_latency_offset() virket ikke</translation>
+        <translation>pa_context_set_port_latency_offset() mislyktes</translation>
     </message>
     <message>
         <location filename="../devicewidget.cc" line="226"/>
@@ -172,7 +172,7 @@
     <message>
         <location filename="../devicewidget.cc" line="227"/>
         <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
-        <translation>Du må lase inn module-device-manager i PulseAudio-serveren for å kunne gi nytt navn til enheter</translation>
+        <translation>Du må laste inn module-device-manager i PulseAudio-serveren for å kunne gi nytt navn til enheter</translation>
     </message>
     <message>
         <location filename="../devicewidget.cc" line="233"/>
@@ -182,7 +182,7 @@
     <message>
         <location filename="../devicewidget.cc" line="240"/>
         <source>pa_ext_device_manager_set_device_description() failed</source>
-        <translation>pa_ext_device_manager_set_device_description() virket ikke</translation>
+        <translation>pa_ext_device_manager_set_device_description() mislyktes</translation>
     </message>
 </context>
 <context>
@@ -241,7 +241,7 @@
     <message>
         <location filename="../mainwindow.ui" line="209"/>
         <source>Hardware Output Devices</source>
-        <translation>Maskinvare utenheter</translation>
+        <translation>Maskinvareutenheter</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="214"/>
@@ -301,7 +301,7 @@
     <message>
         <location filename="../mainwindow.ui" line="298"/>
         <source>&amp;Configuration</source>
-        <translation></translation>
+        <translation>&amp;Konfigurasjon</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="325"/>
@@ -321,52 +321,52 @@
     <message>
         <location filename="../mainwindow.cc" line="159"/>
         <source> (plugged in)</source>
-        <translation> (plugget i)</translation>
+        <translation> (tilkoblet)</translation>
     </message>
     <message>
         <location filename="../mainwindow.cc" line="163"/>
-        <location filename="../mainwindow.cc" line="258"/>
+        <location filename="../mainwindow.cc" line="257"/>
         <source> (unavailable)</source>
         <translation> (ikke tilgjengelig)</translation>
     </message>
     <message>
         <location filename="../mainwindow.cc" line="165"/>
-        <location filename="../mainwindow.cc" line="255"/>
+        <location filename="../mainwindow.cc" line="254"/>
         <source> (unplugged)</source>
-        <translation> (plugget ut)</translation>
+        <translation> (frakoblet)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="389"/>
+        <location filename="../mainwindow.cc" line="388"/>
         <source>Failed to read data from stream</source>
         <translation>Klarte ikke å lese data fra strøm</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="433"/>
+        <location filename="../mainwindow.cc" line="432"/>
         <source>Peak detect</source>
         <translation>Overstyringsoppdaging</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="434"/>
+        <location filename="../mainwindow.cc" line="433"/>
         <source>Failed to create monitoring stream</source>
         <translation>Klarte ikke å lage monitorstrøm</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="449"/>
+        <location filename="../mainwindow.cc" line="448"/>
         <source>Failed to connect monitoring stream</source>
         <translation>Klarte ikke å koble til monitorstrøm</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="588"/>
+        <location filename="../mainwindow.cc" line="587"/>
         <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
         <translation>Ignorerer sink-input fordi den er satt opp til å håndteres som en hendelse og dermed blir håndtert av Event widgeten</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="760"/>
+        <location filename="../mainwindow.cc" line="759"/>
         <source>System Sounds</source>
         <translation>Systemlyder</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cc" line="1090"/>
+        <location filename="../mainwindow.cc" line="1089"/>
         <source>Establishing connection to PulseAudio. Please wait...</source>
         <translation>Setter opp forbindelse til PulseAudio. Vennligst vent...</translation>
     </message>
@@ -422,7 +422,7 @@
     <message>
         <location filename="../pavucontrol.cc" line="263"/>
         <source>pa_ext_stream_restore_read() failed</source>
-        <translation>pa_ext_stream_restore_read() virket ikke</translation>
+        <translation>pa_ext_stream_restore_read() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="281"/>
@@ -433,7 +433,7 @@
     <message>
         <location filename="../pavucontrol.cc" line="302"/>
         <source>pa_ext_device_restore_read_sink_formats() failed</source>
-        <translation>pa_ext_device_restore_read_sink_formats() virket ikke</translation>
+        <translation>pa_ext_device_restore_read_sink_formats() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="320"/>
@@ -444,74 +444,74 @@
     <message>
         <location filename="../pavucontrol.cc" line="339"/>
         <source>pa_ext_device_manager_read() failed</source>
-        <translation>pa_ext_device_manager_read() virket ikke</translation>
+        <translation>pa_ext_device_manager_read() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="356"/>
         <source>pa_context_get_sink_info_by_index() failed</source>
-        <translation>pa_context_get_sink_info_by_index() virket ikke</translation>
+        <translation>pa_context_get_sink_info_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="369"/>
         <source>pa_context_get_source_info_by_index() failed</source>
-        <translation>pa_context_get_source_info_by_index() virket ikke</translation>
+        <translation>pa_context_get_source_info_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="382"/>
         <location filename="../pavucontrol.cc" line="395"/>
         <source>pa_context_get_sink_input_info() failed</source>
-        <translation>pa_context_get_sink_input_info() virket ikke</translation>
+        <translation>pa_context_get_sink_input_info() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="408"/>
         <source>pa_context_get_client_info() failed</source>
-        <translation>pa_context_get_client_info() virket ikke</translation>
+        <translation>pa_context_get_client_info() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="418"/>
         <location filename="../pavucontrol.cc" line="483"/>
         <source>pa_context_get_server_info() failed</source>
-        <translation>pa_context_get_server_info() virket ikke</translation>
+        <translation>pa_context_get_server_info() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="431"/>
         <source>pa_context_get_card_info_by_index() failed</source>
-        <translation>pa_context_get_card_info_by_index() virket ikke</translation>
+        <translation>pa_context_get_card_info_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="474"/>
         <source>pa_context_subscribe() failed</source>
-        <translation>pa_context_subscribe() virket ikke</translation>
+        <translation>pa_context_subscribe() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="490"/>
         <source>pa_context_client_info_list() failed</source>
-        <translation>pa_context_client_info_list() virket ikke</translation>
+        <translation>pa_context_client_info_list() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="497"/>
         <source>pa_context_get_card_info_list() failed</source>
-        <translation>pa_context_get_card_info_list() virket ikke</translation>
+        <translation>pa_context_get_card_info_list() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="504"/>
         <source>pa_context_get_sink_info_list() failed</source>
-        <translation>pa_context_get_sink_info_list() virket ikke</translation>
+        <translation>pa_context_get_sink_info_list() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="511"/>
         <source>pa_context_get_source_info_list() failed</source>
-        <translation>pa_context_get_source_info_list() virket ikke</translation>
+        <translation>pa_context_get_source_info_list() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="518"/>
         <source>pa_context_get_sink_input_info_list() failed</source>
-        <translation>pa_context_get_sink_input_info_list() virket ikke</translation>
+        <translation>pa_context_get_sink_input_info_list() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="525"/>
         <source>pa_context_get_source_output_info_list() failed</source>
-        <translation>pa_context_get_source_output_info_list() virket ikke</translation>
+        <translation>pa_context_get_source_output_info_list() mislyktes</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="584"/>
@@ -534,7 +534,7 @@ or default-server in client.conf is misconfigured.
 This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
 If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
 run start-pulseaudio-x11 manually.</source>
-        <translation>Forbindelsen til PulseAudio virket ikke. Prøver igjen om 5 sekunder
+        <translation>Forbindelsen til PulseAudio mislyktes. Prøver igjen om 5 sekunder
 
 Denne gangen er det sannsynligvis fordi PULSE_SERVER i skrivebordsmiljøet eller X11 Root Window Properties
 eller i standard-serveren i client.conf er feilinnstilt.
@@ -568,7 +568,7 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../rolewidget.cc" line="59"/>
         <source>pa_ext_stream_restore_write() failed</source>
-        <translation>pa_ext_stream_restore_write() virket ikke</translation>
+        <translation>pa_ext_stream_restore_write() mislyktes</translation>
     </message>
 </context>
 <context>
@@ -576,7 +576,7 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../sinkinputwidget.cc" line="36"/>
         <source>on</source>
-        <translation></translation>
+        <translation>på</translation>
     </message>
     <message>
         <location filename="../sinkinputwidget.cc" line="39"/>
@@ -591,22 +591,22 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../sinkinputwidget.cc" line="64"/>
         <source>pa_context_set_sink_input_volume() failed</source>
-        <translation>pa_context_set_sink_input_volume() virket ikke</translation>
+        <translation>pa_context_set_sink_input_volume() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkinputwidget.cc" line="79"/>
         <source>pa_context_set_sink_input_mute() failed</source>
-        <translation>pa_context_set_sink_input_mute() virket ikke</translation>
+        <translation>pa_context_set_sink_input_mute() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkinputwidget.cc" line="89"/>
         <source>pa_context_kill_sink_input() failed</source>
-        <translation>pa_context_kill_sink_input() virket ikke</translation>
+        <translation>pa_context_kill_sink_input() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkinputwidget.cc" line="114"/>
         <source>pa_context_move_sink_input_by_index() failed</source>
-        <translation>pa_context_move_sink_input_by_index() virket ikke</translation>
+        <translation>pa_context_move_sink_input_by_index() mislyktes</translation>
     </message>
 </context>
 <context>
@@ -614,33 +614,33 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../sinkwidget.cc" line="81"/>
         <source>pa_context_set_sink_volume_by_index() failed</source>
-        <translation>pa_context_set_sink_volume_by_index() virket ikke</translation>
+        <translation>pa_context_set_sink_volume_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkwidget.cc" line="96"/>
         <source>pa_context_set_sink_mute_by_index() failed</source>
-        <translation>pa_context_set_sink_mute_by_index() virket ikke</translation>
+        <translation>pa_context_set_sink_mute_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkwidget.cc" line="110"/>
         <source>pa_context_set_default_sink() failed</source>
-        <translation>pa_context_set_default_sink() virket ikke</translation>
+        <translation>pa_context_set_default_sink() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkwidget.cc" line="126"/>
         <source>pa_context_set_sink_port_by_index() failed</source>
-        <translation>pa_context_set_sink_port_by_index() virket ikke</translation>
+        <translation>pa_context_set_sink_port_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../sinkwidget.cc" line="166"/>
         <source>pa_ext_device_restore_save_sink_formats() failed</source>
-        <translation>pa_ext_device_restore_save_sink_formats() virket ikke</translation>
+        <translation>pa_ext_device_restore_save_sink_formats() mislyktes</translation>
     </message>
 </context>
 <context>
     <name>SourceOutputWidget</name>
     <message>
-        <location filename="../sourceoutputwidget.cc" line="36"/>
+        <location filename="../sourceoutputwidget.cc" line="35"/>
         <source>from</source>
         <translation>fra</translation>
     </message>
@@ -657,22 +657,22 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../sourceoutputwidget.cc" line="72"/>
         <source>pa_context_set_source_output_volume() failed</source>
-        <translation>pa_context_set_source_output_volume() virket ikke</translation>
+        <translation>pa_context_set_source_output_volume() mislyktes</translation>
     </message>
     <message>
         <location filename="../sourceoutputwidget.cc" line="87"/>
         <source>pa_context_set_source_output_mute() failed</source>
-        <translation>pa_context_set_source_output_mute() virket ikke</translation>
+        <translation>pa_context_set_source_output_mute() mislyktes</translation>
     </message>
     <message>
         <location filename="../sourceoutputwidget.cc" line="98"/>
         <source>pa_context_kill_source_output() failed</source>
-        <translation>pa_context_kill_source_output() virket ikke</translation>
+        <translation>pa_context_kill_source_output() mislyktes</translation>
     </message>
     <message>
         <location filename="../sourceoutputwidget.cc" line="125"/>
         <source>pa_context_move_source_output_by_index() failed</source>
-        <translation>pa_context_move_source_output_by_index() virket ikke</translation>
+        <translation>pa_context_move_source_output_by_index() mislyktes</translation>
     </message>
 </context>
 <context>
@@ -680,22 +680,22 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../sourcewidget.cc" line="35"/>
         <source>pa_context_set_source_volume_by_index() failed</source>
-        <translation>pa_context_set_source_volume_by_index() virket ikke</translation>
+        <translation>pa_context_set_source_volume_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../sourcewidget.cc" line="50"/>
         <source>pa_context_set_source_mute_by_index() failed</source>
-        <translation>pa_context_set_source_mute_by_index() virket ikke</translation>
+        <translation>pa_context_set_source_mute_by_index() mislyktes</translation>
     </message>
     <message>
         <location filename="../sourcewidget.cc" line="64"/>
         <source>pa_context_set_default_source() failed</source>
-        <translation>pa_context_set_default_source() virket ikke</translation>
+        <translation>pa_context_set_default_source() mislyktes</translation>
     </message>
     <message>
         <location filename="../sourcewidget.cc" line="80"/>
         <source>pa_context_set_source_port_by_index() failed</source>
-        <translation>pa_context_set_source_port_by_index() virket ikke</translation>
+        <translation>pa_context_set_source_port_by_index() mislyktes</translation>
     </message>
 </context>
 <context>
@@ -703,7 +703,7 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../streamwidget.ui" line="14"/>
         <source>Form</source>
-        <translation></translation>
+        <translation>Formular</translation>
     </message>
     <message>
         <location filename="../streamwidget.ui" line="32"/>
@@ -713,7 +713,7 @@ burde du kjøre start-pulseaudio-x11 manuelt.</translation>
     <message>
         <location filename="../streamwidget.ui" line="52"/>
         <source>direction</source>
-        <translation></translation>
+        <translation>retning</translation>
     </message>
     <message>
         <location filename="../streamwidget.ui" line="59"/>
